@@ -4,7 +4,6 @@ An application for managing IPython history.
 
 To be invoked as the `ipython history` subcommand.
 """
-from __future__ import print_function
 
 import os
 import sqlite3
@@ -34,15 +33,17 @@ This is an handy alias to `ipython history trim --keep=0`
 class HistoryTrim(BaseIPythonApplication):
     description = trim_hist_help
     
-    backup = Bool(False, config=True,
-        help="Keep the old history file as history.sqlite.<N>")
+    backup = Bool(False,
+        help="Keep the old history file as history.sqlite.<N>"
+        ).tag(config=True)
     
-    keep = Int(1000, config=True,
-        help="Number of recent lines to keep in the database.")
+    keep = Int(1000,
+        help="Number of recent lines to keep in the database."
+        ).tag(config=True)
     
     flags = Dict(dict(
         backup = ({'HistoryTrim' : {'backup' : True}},
-            backup.get_metadata('help')
+            backup.help
         )
     ))
 
@@ -118,17 +119,18 @@ class HistoryTrim(BaseIPythonApplication):
 
 class HistoryClear(HistoryTrim):
     description = clear_hist_help
-    keep = Int(0, config=False,
+    keep = Int(0,
         help="Number of recent lines to keep in the database.")
     
-    force = Bool(False, config=True,
-        help="Don't prompt user for confirmation")
+    force = Bool(False,
+        help="Don't prompt user for confirmation"
+        ).tag(config=True)
     
     flags = Dict(dict(
         force = ({'HistoryClear' : {'force' : True}},
-            force.get_metadata('help')),
+            force.help),
         f = ({'HistoryTrim' : {'force' : True}},
-            force.get_metadata('help')
+            force.help
         )
     ))
     aliases = Dict()
