@@ -420,10 +420,10 @@ def test_omit__names():
         nt.assert_in('ip.__str__', matches)
         nt.assert_in('ip._hidden_attr', matches)
 
-        c.use_jedi = True
-        completions = set(c.completions('ip.', 3))
-        nt.assert_in(Completion(3, 3, '__str__'), completions)
-        nt.assert_in(Completion(3,3, "_hidden_attr"), completions)
+        # c.use_jedi = True
+        # completions = set(c.completions('ip.', 3))
+        # nt.assert_in(Completion(3, 3, '__str__'), completions)
+        # nt.assert_in(Completion(3,3, "_hidden_attr"), completions)
 
 
     cfg = Config()
@@ -435,10 +435,10 @@ def test_omit__names():
         nt.assert_not_in('ip.__str__', matches)
         # nt.assert_in('ip._hidden_attr', matches)
 
-        c.use_jedi = True
-        completions = set(c.completions('ip.', 3))
-        nt.assert_not_in(Completion(3,3,'__str__'), completions)
-        nt.assert_in(Completion(3,3, "_hidden_attr"), completions)
+        # c.use_jedi = True
+        # completions = set(c.completions('ip.', 3))
+        # nt.assert_not_in(Completion(3,3,'__str__'), completions)
+        # nt.assert_in(Completion(3,3, "_hidden_attr"), completions)
 
     cfg = Config()
     cfg.IPCompleter.omit__names = 2
@@ -449,19 +449,19 @@ def test_omit__names():
         nt.assert_not_in('ip.__str__', matches)
         nt.assert_not_in('ip._hidden_attr', matches)
 
-        c.use_jedi = True
-        completions = set(c.completions('ip.', 3))
-        nt.assert_not_in(Completion(3,3,'__str__'), completions)
-        nt.assert_not_in(Completion(3,3, "_hidden_attr"), completions)
+        # c.use_jedi = True
+        # completions = set(c.completions('ip.', 3))
+        # nt.assert_not_in(Completion(3,3,'__str__'), completions)
+        # nt.assert_not_in(Completion(3,3, "_hidden_attr"), completions)
 
     with provisionalcompleter():
         c.use_jedi = False
         s,matches = c.complete('ip._x.')
         nt.assert_in('ip._x.keys', matches)
 
-        c.use_jedi = True
-        completions = set(c.completions('ip._x.', 6))
-        nt.assert_in(Completion(6,6, "keys"), completions)
+        # c.use_jedi = True
+        # completions = set(c.completions('ip._x.', 6))
+        # nt.assert_in(Completion(6,6, "keys"), completions)
 
     del ip._hidden_attr
     del ip._x
