@@ -116,7 +116,6 @@ import traceback
 import types
 import weakref
 from importlib import import_module
-from IPython.utils.py3compat import PY3
 from imp import reload
 
 from IPython.utils import openpy
@@ -185,7 +184,7 @@ class ModuleReloader(object):
         if not hasattr(module, '__file__') or module.__file__ is None:
             return None, None
 
-        if getattr(module, '__name__', None) in ['__mp_main__', '__main__']:
+        if getattr(module, '__name__', None) in [None, '__mp_main__', '__main__']:
             # we cannot reload(__main__) or reload(__mp_main__)
             return None, None
 
